Learn R Programming

rFDSN (version 0.0.0)

FDSNGetNetworks: Download network and station data from FDSN.

Description

This function gathers information about stations and networks from the International Federation of Digital Seismograph Networks. The available subsetting parameters can be viewed by calling FDSNParameterList.

Usage

FDSNGetNetworks(base.url, parameters,verbose = TRUE)

Arguments

base.url
The address of a FDSN server.
parameters
Selection parameters to subset results, see FDSNParameterList for available inputs and examples below for usage.
verbose
If TRUE, print the URL used to gather the station and network. Default TRUE.

Value

network
A structure with seismic network information

References

http://www.fdsn.org/webservices/

See Also

FDSNParameterList

Examples

Run this code

## Not run: 
# 
# #Find all stations with operating vertical seismic channels
# #within 2 degrees of Socorro, New Mexico,
# #between 2010 and 2013
# #available through the IRIS DMC server.
# 
# #IRIS station server
# base.url <- "http://service.iris.edu/fdsnws/station/1/"
# 
# #Selection criteria
# parameters <- list(
#     name = c(
#     "latitude",
#     "longitude",
#     "maxradius",
#     "cha",
#     "start",
#     "end"),
#     value = c(
#     34.068110, #Latitude
#     -106.901847, #Longitude
#     2, #Degrees from center point
#     "*Z",#Channel (with wildcards)
#     "2010-01-01", #Start time
#     "2014-01-01") #End time
#     )
# 
# networks <- FDSNGetNetworks(base.url, parameters)
# 
# 
# ## End(Not run)

Run the code above in your browser using DataLab