Learn R Programming

rFDSN (version 0.0.0)

FDSNGetTimeSeries: Download sensor time series from FDSN.

Description

This function gathers earthquake data from the International Federation of Digital Seismograph Networks in miniseed format. The available subsetting parameters can be viewed by calling FDSNParameterList.

Usage

FDSNGetTimeSeries(base.url, parameters, save.file = "result.mseed", save.dir = ".", verbose = TRUE)

Arguments

base.url
The address of a FDSN server.
parameters
Time series selection parameters, see FDSNParameterList for available inputs and examples below for usage.
save.file
What name to give the miniseed file when it has been downloaded.
save.dir
Where to save the miniseed file, defaults to the current directory.
verbose
If TRUE, download progress is displayed.

Value

file.name
The location of the downloaded file

References

http://www.fdsn.org/webservices/

See Also

FDSNParameterList

Examples

Run this code

## Not run: 
# 
# #Download pressure data at station Y22D on August 9, 2014
# 
# #IRIS data download server
# base.url <- "http://service.iris.edu/fdsnws/dataselect/1/"
# parameters <- list(
#     name = c(
#     "sta",
#     "cha",
#     "start",
#     "end"),
#     value = c(
#     "Y22D", #Station name
#     "BDF", #SEED channel name
#     "2014-08-09T00:00:00.000", #Midnight GMT
#     "2014-08-09T23:59:59.999") #Midnight GMT
#    )
# miniseed.file <- FDSNGetTimeSeries(base.url, parameters, save.file = "Y22D_BDF.mseed")
# 
# 
# ## End(Not run)

Run the code above in your browser using DataLab