Learn R Programming

rFDSN (version 0.0.0)

FDSNParameterList: Subset options for FDSN

Description

A list and description of subset options for FDSNGetEvents, FDSNGetNetworks, and FDSNGetTimeSeries.

Usage

FDSNParameterList(interface)

Arguments

interface
Whether to show parameter list for "station", "dataselect" or "event".

Value

parameters
A list describing the parameters available for data subsetting through FDSN

See Also

FDSNGetEvents, FDSNGetNetworks, FDSNGetTimeSeries

Examples

Run this code


station.params <- FDSNParameterList("station")
timeseries.params <- FDSNParameterList("dataselect")
event.params <- FDSNParameterList("event")

Run the code above in your browser using DataLab